eric7/VCS/VersionControl.py

branch
eric7
changeset 8620
84f7f7867b5f
parent 8358
144a6b854f70
child 8621
8c9f41115c04
--- a/eric7/VCS/VersionControl.py	Mon Sep 20 07:29:27 2021 +0200
+++ b/eric7/VCS/VersionControl.py	Mon Sep 20 19:47:18 2021 +0200
@@ -29,7 +29,10 @@
     It defines the vcs interface to be implemented by subclasses
     and the common methods.
     
+    @signal committed() emitted after the commit action has completed
     @signal vcsStatusMonitorData(list of str) emitted to update the VCS status
+    @signal vcsStatusMonitorAllData(dict) emitted to signal all VCS status
+        (key is project relative file name, value is status)
     @signal vcsStatusMonitorStatus(str, str) emitted to signal the status of
         the monitoring thread (ok, nok, op, off) and a status message
     @signal vcsStatusMonitorInfo(str) emitted to signal some info of the
@@ -37,7 +40,9 @@
     @signal vcsStatusChanged() emitted to indicate a change of the overall
         VCS status
     """
+    committed = pyqtSignal()
     vcsStatusMonitorData = pyqtSignal(list)
+    vcsStatusMonitorAllData = pyqtSignal(dict)
     vcsStatusMonitorStatus = pyqtSignal(str, str)
     vcsStatusMonitorInfo = pyqtSignal(str)
     vcsStatusChanged = pyqtSignal()
@@ -685,7 +690,7 @@
 
     def __statusMonitorData(self, statusList):
         """
         Private method to receive the status monitor status.
         
         It simply re-emits the received status list.
         
@@ -695,6 +700,18 @@
         self.vcsStatusMonitorData.emit(statusList)
         QCoreApplication.processEvents()
     
+    def __statusMonitorAllData(self, statusDict):
+        """
+        Private method to receive all status monitor data.
+        
+        It simply re-emits the received status list.
+        
+        @param statusDict dictionary of status records
+        @type dict
+        """
+        self.vcsStatusMonitorAllData.emit(statusDict)
+        QCoreApplication.processEvents()
+    
     def __statusMonitorInfo(self, info):
         """
         Private slot to receive the status monitor info message.
@@ -726,6 +743,9 @@
                 self.statusMonitorThread.vcsStatusMonitorData.connect(
                     self.__statusMonitorData,
                     Qt.ConnectionType.QueuedConnection)
+                self.statusMonitorThread.vcsStatusMonitorAllData.connect(
+                    self.__statusMonitorAllData,
+                    Qt.ConnectionType.QueuedConnection)
                 self.statusMonitorThread.vcsStatusMonitorStatus.connect(
                     self.__statusMonitorStatus,
                     Qt.ConnectionType.QueuedConnection)
@@ -747,6 +767,8 @@
             self.__statusMonitorData(["--RESET--"])
             self.statusMonitorThread.vcsStatusMonitorData.disconnect(
                 self.__statusMonitorData)
+            self.statusMonitorThread.vcsStatusMonitorAllData.disconnect(
+                self.__statusMonitorAllData)
             self.statusMonitorThread.vcsStatusMonitorStatus.disconnect(
                 self.__statusMonitorStatus)
             self.statusMonitorThread.vcsStatusMonitorInfo.disconnect(
@@ -685,7 +690,7 @@
     def __statusMonitorData(self, statusList):
         """
-        Private method to receive the status monitor status.
+        Private method to receive the status monitor data update.
         
         It simply re-emits the received status list.

eric ide

mercurial